@@ -17,11 +17,12 @@ testthat::test_that(
     app_driver <- shinytest2::AppDriver$new(
       app_driver_osivmm(),
       name = "osivmm",
-      variant = "app_driver_osivmm_ui"
+      variant = "app_driver_osivmm_ui",
+      wait = FALSE
     )
-    app_driver$wait_for_idle(timeout = default_idle_timeout)
-    testthat::expect_false(is_visible("#a1-label", app_driver))
-    testthat::expect_true(is_visible("#a2-label", app_driver))
+    app_driver$wait_for_idle()
+    expect_hidden("#a1-label", app_driver)
+    expect_visible("#a2-label", app_driver)
     app_driver$stop()
   }
 )
