@@ -13,7 +13,7 @@ testthat::test_that("table_with_settings_srv: assertions", {
   for (arg in args) {
     testthat::expect_error(
       shiny::testServer(
-        teal.widgets:::table_with_settings_srv,
+        teal.widgets::table_with_settings_srv,
         args = arg
       ),
       "Assertion"
@@ -23,7 +23,7 @@ testthat::test_that("table_with_settings_srv: assertions", {
 
 testthat::test_that("table_with_settings_srv: hiding works", {
   shiny::testServer(
-    teal.widgets:::table_with_settings_srv,
+    teal.widgets::table_with_settings_srv,
     args = list(table_r = table_r, show_hide_signal = reactive(FALSE)),
     expr = {
       testthat::expect_silent(output$table_out_modal$html)
@@ -31,20 +31,22 @@ testthat::test_that("table_with_settings_srv: hiding works", {
   )
 })
 
-testthat::test_that("table_with_settings_srv: return html table", {
+testthat::test_that("table_with_settings_srv: return html table with content", {
   shiny::testServer(
-    teal.widgets:::table_with_settings_srv,
+    teal.widgets::table_with_settings_srv,
     args = list(id = "tws", table_r = table_r),
     expr = {
-      testthat::expect_s3_class(output$table_out_modal$html, "html")
-      testthat::expect_equal(output$table_out_main$html, output$table_out_modal$html)
+      html_content <- as.character(output$table_out_main$html)
+      testthat::expect_s3_class(output$table_out_main$html, "html")
+      testthat::expect_true(grepl("Species|setosa|versicolor|virginica", html_content, ignore.case = TRUE))
+      testthat::expect_true(grepl("Mean|5\\.0", html_content))
     }
   )
 })
 
 testthat::test_that("table_with_settings_srv: expand works", {
   shiny::testServer(
-    teal.widgets:::table_with_settings_srv,
+    teal.widgets::table_with_settings_srv,
     args = list(id = "tws", table_r = table_r),
     expr = {
       session$setInputs(`expand` = TRUE)
@@ -168,3 +170,37 @@ testthat::test_that("type_download_srv_table: content of the table, txt", {
     }
   )
 })
+
+testthat::test_that("table_with_settings_srv: gtsummary table renders with content", {
+  gtsummary_r <- shiny::reactive({
+    gtsummary::tbl_summary(mtcars[1:5, 1:3])
+  })
+
+  shiny::testServer(
+    teal.widgets::table_with_settings_srv,
+    args = list(id = "tws", table_r = gtsummary_r),
+    expr = {
+      html_content <- as.character(output$table_out_main$html)
+      testthat::expect_s3_class(output$table_out_main$html, "html")
+      testthat::expect_true(grepl("mpg|cyl|disp", html_content, ignore.case = TRUE))
+      testthat::expect_true(grepl("<table", html_content, ignore.case = TRUE))
+    }
+  )
+})
+
+testthat::test_that("table_with_settings_srv: gt table renders with content", {
+  gt_r <- shiny::reactive({
+    gt::gt(mtcars[1:5, 1:3])
+  })
+
+  shiny::testServer(
+    teal.widgets::table_with_settings_srv,
+    args = list(id = "tws", table_r = gt_r),
+    expr = {
+      html_content <- as.character(output$table_out_main$html)
+      testthat::expect_s3_class(output$table_out_main$html, "html")
+      testthat::expect_true(grepl("mpg|cyl|disp", html_content, ignore.case = TRUE))
+      testthat::expect_true(grepl("<table", html_content, ignore.case = TRUE))
+    }
+  )
+})
